# Century - A ORM for SQL Databases

A simple ORM for SQL Databases. It is a simple ORM that can be used to create a database and tables. It can also be used to insert, update, delete and select data from the database.

CREATED BY: [Md. Almas Ali](https://github.com/Almas-Ali)

